@@ -18,26 +18,25 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 #include "server.h"
-#include <QStringList>
 #include <QHostAddress>
-#include <qsocketnotifier.h>
-#include <net/socket.h>
+#include <QStringList>
 #include <mse/encryptedpacketsocket.h>
-#include <util/sha1hash.h>
-#include <util/log.h>
-#include <util/functions.h>
-#include <net/portlist.h>
 #include <mse/encryptedserverauthenticate.h>
+#include <net/portlist.h>
+#include <net/socket.h>
+#include <peer/accessmanager.h>
+#include <peer/authenticationmonitor.h>
 #include <peer/peermanager.h>
 #include <peer/serverauthenticate.h>
-#include <peer/authenticationmonitor.h>
-#include <peer/accessmanager.h>
+#include <qsocketnotifier.h>
+#include <util/functions.h>
+#include <util/log.h>
+#include <util/sha1hash.h>
 
 #include "globals.h"
 #include "torrent.h"
 #include <net/serversocket.h>
 
-
 namespace bt
 {
 typedef QSharedPointer<net::ServerSocket> ServerSocketPtr;
@@ -45,7 +44,8 @@ typedef QSharedPointer<net::ServerSocket> ServerSocketPtr;
 class Server::Private : public net::ServerSocket::ConnectionHandler
 {
 public:
-    Private(Server* p) : p(p)
+    Private(Server *p)
+        : p(p)
     {
     }
 
@@ -58,13 +58,13 @@ public:
         sockets.clear();
     }
 
-    void newConnection(int fd, const net::Address & addr) override
+    void newConnection(int fd, const net::Address &addr) override
     {
         mse::EncryptedPacketSocket::Ptr s(new mse::EncryptedPacketSocket(fd, addr.ipVersion()));
         p->newConnection(s);
     }
 
-    void add(const QString & ip, bt::Uint16 port)
+    void add(const QString &ip, bt::Uint16 port)
     {
         ServerSocketPtr sock(new net::ServerSocket(this));
         if (sock->bind(ip, port)) {
@@ -72,16 +72,15 @@ public:
         }
     }
 
-
-    Server* p;
+    Server *p;
     QList<ServerSocketPtr> sockets;
 };
 
-Server::Server() : d(new Private(this))
+Server::Server()
+    : d(new Private(this))
 {
 }
 
-
 Server::~Server()
 {
     Globals::instance().getPortList().removePort(port, net::TCP);
@@ -97,7 +96,7 @@ bool Server::changePort(Uint16 p)
     d->reset();
 
     const QStringList possible = bindAddresses();
-    for (const QString & addr : possible) {
+    for (const QString &addr : possible) {
         d->add(addr, p);
     }
 
@@ -115,4 +114,3 @@ bool Server::changePort(Uint16 p)
 }
 
 }
-
