@@ -51,7 +51,7 @@ public:
     ~UDPTracker() override;
 
     void start() override;
-    void stop(WaitJob *wjob = 0) override;
+    void stop(WaitJob *wjob = nullptr) override;
     void completed() override;
     Uint32 failureCount() const override
     {
